
!SmalltalkImage methodsFor: '*DevPacerPharo14' stamp: 'hjo 5/11/2012 19:26'!
snapshot: save andQuit: quit
	"Mark the changes file and close all files as part of #processShutdownList.
	If save is true, save the current state of this Smalltalk in the image file.
	If quit is true, then exit to the outer OS shell.
	The latter part of this method runs when resuming a previously saved image. This resume logic checks for a document file to process when starting up."

	| snapshotResult resuming startupErrors |
	"BEGIN PATCH DevPacer"
	save ifTrue: [ImageSavePacer systemSaved].
	"END PATCH DevPacer"
	Object flushDependents.
	Object flushEvents.

	self addSnapshotRecord: save andQuit: quit.
	self processShutDownList: quit.
									
	save
		ifTrue: [ 
			snapshotResult := self snapshotPrimitive.	"<-- PC frozen here on image file"
			resuming := snapshotResult == true ]
		ifFalse: [ resuming := false ].
	(quit and: [ resuming not ])
		ifTrue: [ self quitPrimitive ].
	
	self vm setGCParameters.
	
	deferredStartupActions := nil.
	resuming
		ifTrue: [ Smalltalk clearExternalObjects ].
	
	startupErrors := OrderedCollection new.
	
	UIManager default boot: resuming during: [
		startupErrors addAll: (self processStartUpList: resuming).
		resuming
			ifTrue: [ self recordStartupStamp ]].
	startupErrors addAll: (self executeDeferredStartupActions: resuming).
	
	startupErrors isEmpty 
		ifFalse: [ self handleStartupErrors: startupErrors ].
		
	snapshotResult == nil
		ifTrue: [ self error: 'Failed to write image file (disk full?)' ].
		
	^ resuming! !

!TestRunner methodsFor: '*DevPacerPharo14' stamp: 'hjo 5/11/2012 19:27'!
updateResults
	"<lint: #expect rule: #guardingClause>"
	"<lint: #expect rule: #longMethods>"

	self updateStatus: false.
	
	"BEGIN PATCH DevPacer"
	(result hasPassed and: [result runCount > 0])
		ifTrue: [TestPacer colorOfTestRunnerGotGreen ]
		ifFalse: [TestPacer colorOfTestRunnerGotNotGreen ].
	"END PATCH DevPacer"
	
	failedList size = result failures size ifFalse: [
		failedList := result failures asArray
			sort: [ :a :b | a printString <= b printString ].
		failedSelected := nil.
		self 
			changed: #failedList; 
			changed: #failedSelected;
			changed: #hasFailures;
			changed: #hasProgress;
			changed: #hasFailuresOrErrors  ].
	errorList size = result errors size ifFalse: [
		errorList := result errors asArray
			sort: [ :a :b | a printString <= b printString ].
		errorSelected := nil.
		self 
			changed: #errorList; 
			changed: #errorSelected;
			changed: #hasErrors;
			changed: #hasProgress;
			changed: #hasFailuresOrErrors  ].! !

!ImageSavePacer classSide methodsFor: '*DevPacerPharo14' stamp: 'hjo 4/20/2012 17:30'!
initialize

	self registerToAnnouncements.! !

!ImageSavePacer classSide methodsFor: '*DevPacerPharo14' stamp: 'hjo 4/20/2012 15:13'!
registerToAnnouncements

	SystemAnnouncer announcer weak
		on: CategoryAdded send: #systemChanged to: self;
		on: CategoryRemoved send: #systemChanged to: self;
		on: CategoryRenamed send: #systemChanged to: self;
		on: ClassAdded send: #systemChanged to: self;
		on: ClassCommented send: #systemChanged to: self;
		on: ClassModifiedClassDefinition send: #systemChanged to: self;
		on: ClassRecategorized send: #systemChanged to: self;
		on: ClassRemoved send: #systemChanged to: self;
		on: ClassRenamed send: #systemChanged to: self;
		on: ClassReorganized send: #systemChanged to: self;
		on: MethodAdded send: #systemChanged to: self;
		on: MethodModified send: #systemChanged to: self;
		on: MethodRecategorized send: #systemChanged to: self;
		on: MethodRemoved send: #systemChanged to: self;
		on: ProtocolAdded send: #systemChanged to: self;
		on: ProtocolRemoved send: #systemChanged to: self;
		on: UnknownSystemChange send: #systemChanged to: self
! !

!MCRepository methodsFor: '*DevPacerPharo14' stamp: 'hjo 5/31/2012 12:43'!
storeVersion: aVersion
	self basicStoreVersion: (self prepareVersionForStorage: aVersion).
	ImageSavePacer systemChanged.
	self sendNotificationsForVersion: aVersion..! !
ImageSavePacer initialize!
